@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Attribute::Handlers;
 
-our $VERSION = sprintf "%d.%02d", q$Revision: 1.1 $ =~ /(\d+)/g;
+our $VERSION = sprintf "%d.%02d", q$Revision: 1.2 $ =~ /(\d+)/g;
 
 sub UNIVERSAL::SigHandler : ATTR(CODE) {
 	my ($symbol, $data) = @_[1,4];
@@ -43,7 +43,7 @@ author.
 
 Marcel Grunauer, <marcel@codewerk.com>
 
-Dan Kogai, <dankogai@dan.co.jp>
+Dan Kogai, C<< <dankogai+cpan at gmail.com> >>
 
 =head1 COPYRIGHT
 
